OC.L10N.register(
    "core",
    {
    "Please select a file." : "Seleiciona un ficheru.",
    "File is too big" : "El ficheru ye mui grande",
    "The selected file is not an image." : "El ficheru seleicionáu nun ye una imaxe.",
    "The selected file cannot be read." : "El ficheru seleicionáu nun se pue lleer.",
    "The file was uploaded" : "Xubióse'l ficheru",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El ficheru xubíu supera la direutiva «upload_max_filesize» del ficheru php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El ficheru xubíu supera la direutiva «MAX_FILE_SIZE» que s'especificó nel formulariu HTML",
    "The file was only partially uploaded" : "El ficheru xubióse parcialmente",
    "No file was uploaded" : "Nun se xubió nengún ficheru",
    "Missing a temporary folder" : "Falta una carpeta temporal",
    "Could not write file to disk" : "Nun se pudo escribir el ficheru nel discu",
    "A PHP extension stopped the file upload" : "Una estensión PHP paró la xuba de ficheros",
    "Invalid file provided" : "Fornióse un ficheru inválidu",
    "No image or file provided" : "Nun se fornió nenguna imaxe o ficheru",
    "Unknown filetype" : "El tipu de ficheru ye inválidu",
    "An error occurred. Please contact your admin." : "Prodúxose un error. Ponte en contautu cola alministración.",
    "Invalid image" : "La imaxe ye inválida",
    "State token does not match" : "El pase d'estáu nun concasa",
    "Invalid app password" : "La contraseña de l'aplicación ye inválida",
    "Could not complete login" : "Nun se pudo completar l'aniciu de la sesión",
    "State token missing" : "Falta'l pase d'estáu",
    "Your login token is invalid or has expired" : "El pase d'aniciu de sesión ye inválidu o caducó",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Esta versión comunitaria de Nextcloud nun tien sofitu y los avisos automáticos tán llendaos.",
    "Login" : "Aniciar la sesión",
    "Unsupported email length (>255)" : "La llongura de la direición de corréu electrónicu nun ye compatible (>255)",
    "Password reset is disabled" : "El reaniciu de la contraseña ta desactiváu",
    "Could not reset password because the token is expired" : "Nun se pudo reafitar la contraseña porque'l pase caducó",
    "Could not reset password because the token is invalid" : "Nun se pudo reafitar la contraseña porque'l pase ye inválidu",
    "Password is too long. Maximum allowed length is 469 characters." : "La contraseña ye mui llonga. La llongura máxima permitida ye de 469 caráuteres.",
    "%s password reset" : "Reanciu de la contraseña de: %s",
    "Password reset" : "Reaniciu de la contraseña",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Calca'l botón siguiente pa reaniciar la contraseña. Si nun solicitesti esta aición, inora'l mensaxe.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Calca l'enllaz siguiente pa reaniciar la contraseña. Si nun solicitesti esta aición, inora'l mensaxe.",
    "Reset your password" : "Reaniciar la contraseña",
    "The given provider is not available" : "El fornidor apurríu nun ta disponible",
    "Task not found" : "Nun s'atopó la xera",
    "Internal error" : "Error internu",
    "Not found" : "Nun s'atopó",
    "Requested task type does not exist" : "El tipu de xera solicitada nun esiste",
    "Necessary language model provider is not available" : "El modelu llingüísticu necesariu nun ta disponible",
    "No text to image provider is available" : "Nun hai nengún fornidor de testu a imaxe disponible",
    "Image not found" : "Nun s'atopó la imaxe",
    "No translation provider available" : "Nun hai nengún fornidor de traducciones disponible",
    "Could not detect language" : "Nun se pudo detectar la llingua",
    "Unable to translate" : "Nun ye posible traducir",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Pasos de la reparación:",
    "Repair info:" : "Información de la reparación:",
    "Repair warning:" : "Alvertencia de la reparación:",
    "Repair error:" : "Error de la reparación:",
    "Nextcloud Server" : "Sirvidor de Nextcloud",
    "Some of your link shares have been removed" : "Quitáronse dalgunos enllaces de los elementos que compartiesti",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Pola mor d'un fallu de seguranza, tuviemos de quitar dalgunos enllaces compartíos. Consulta l'enllaz d'abaxo pa consiguir más información.",
    "The account limit of this instance is reached." : "Algamóse la llende de cuentes d'esta instacia.",
    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Introduz la clave de la soscripción n'aplicación de sofitu p'aumentar la llende de cuentes. Esta aición tamién te concede tolos beneficios que Nextcloud Enterprise ufre, que son mui aconseyables pa compañes.",
    "Learn more ↗" : "Saber más ↗",
    "Preparing update" : "Tresnando l'anovamientu",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "Usa l'anovador de la llinia de comandos porque l'anovamientu pel restolador ta desactiváu nel ficheru config.php.",
    "Turned on maintenance mode" : "Activóse'l mou de caltenimientu",
    "Turned off maintenance mode" : "Desactivóse'l mou de caltenimientu",
    "Maintenance mode is kept active" : "El mou de caltenimientu sigue activu",
    "Updating database schema" : "Anovando l'esquema de les bases de datos",
    "Updated database" : "Anovóse la base de datos",
    "Update app \"%s\" from App Store" : "Anueva l'aplicación «%s» dende l'App Store",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Comprueba si pue anovase l'esquema de la base de datos de «%s» (esta aición pue tardar munchu tiempu según el tamañu de la base de datos)",
    "Updated \"%1$s\" to %2$s" : "Anovóse «%1$s» a %2$s",
    "Set log level to debug" : "Afitar el nivel de rexistru a «debug»",
    "Reset log level" : "Reanicair el nivel de rexistru",
    "Starting code integrity check" : "Aniciando la comprobación de la integridá del códigu",
    "Finished code integrity check" : "Finó la comprobación de la integridá del códigu",
    "%s (incompatible)" : "%s (incompatible)",
    "The following apps have been disabled: %s" : "Desactiváronse les aplicaciones siguientes: %s",
    "Already up to date" : "Yá s'anovó",
    "Unknown" : "Desconocí­u",
    "PNG image" : "Imaxe PNG",
    "The update is in progress, leaving this page might interrupt the process in some environments." : "L'anovamientu ta en cursu. Ye posible qu'al colar d'esta páxina s'interrumpa'l procesu en dalgunos entornos.",
    "Update to {version}" : "Anovar a la versión {version}",
    "An error occurred." : "Prodúxose un error.",
    "Please reload the page." : "Volvi cargar la páxina.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "L'anovamientu nun foi correutu. Pa consiguir más información, <a href=\"{url}\">comprueba l'artículu del foru</a> que cubre esti problema.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "L'anovamientu nun foi correutu. Informa d'esti problema na <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">comunidá de Nextcloud</a>.",
    "Continue to {productName}" : "Siguir con «{productName}»",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["L'anovamientu foi correutu. Va redirixísete a {productName} en %n segundu.","L'anovamientu foi correutu. Va redirixísete a {productName} en %n segundos."],
    "Applications menu" : "Menú d'aplicaciones",
    "Apps" : "Aplicaciones",
    "More apps" : "Más aplicaciones",
    "_{count} notification_::_{count} notifications_" : ["{count} avisu","{count} avisos"],
    "No" : "Non",
    "Yes" : "Sí",
    "Failed to add the public link to your Nextcloud" : "Nun se pue amestar l'enllaz públicu a esta instancia de Nextcloud",
    "Federated user" : "Usuariu federáu",
    "Create share" : "Crear l'elementu compartíu",
    "Custom date range" : "Intervalu de dates personalizáu",
    "Pick start date" : "Escoyer la data de comienzu",
    "Pick end date" : "Escoyer la data de fin",
    "Search in date range" : "Buscar nun intervalu de dates",
    "Start typing to search" : "Comienza a escribir pa buscar",
    "No matching results" : "Nun hai nengún resultáu que concasare",
    "Today" : "Güei",
    "Last 7 days" : "Los últimos 7 díes",
    "Last 30 days" : "Los últimos 30 díes",
    "This year" : "Esti añu",
    "Last year" : "L'añu pasáu",
    "Unified search" : "Busca unificada",
    "Search apps, files, tags, messages" : "Buscar aplicaciones, ficheros, etiquetes, mensaxes",
    "Places" : "Llugares",
    "Date" : "Data",
    "Search people" : "Buscar persones",
    "People" : "Persones",
    "Filter in current view" : "Peñerar na vista actual",
    "Results" : "Resultaos",
    "Load more results" : "Cargar más resultaos",
    "Search in" : "Buscar en",
    "Log in" : "Aniciar la sesión",
    "Log in to {productName}" : "Aniciar la sesión en: {productName}",
    "Wrong login or password." : "El nomatu o la contraseña nun son correutos.",
    "This account is disabled" : "Esta cuenta ta desactivada",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Dende la to IP, detectemos múltiples intentos d'aniciar la sesión que son inválidos. Poro, el próximu aniciu de la sesión va tardar 30 segundos.",
    "Account name or email" : "Nome o direición de corréu de la cuenta",
    "Server side authentication failed!" : "¡L'autenticación de llau del sirvidor falló!",
    "Please contact your administrator." : "Ponte en contautu cola alministración.",
    "An internal error occurred." : "Prodúxose un error internu.",
    "Please try again or contact your administrator." : "Volvi tentalo o ponte en contautu cola alministración.",
    "Password" : "Contraseña",
    "Log in with a device" : "Aniciar la sesión con un preséu",
    "Login or email" : "Cuenta o direición de corréu electrónicu",
    "Your account is not setup for passwordless login." : "La cuenta nun ta configurada p'aniciar la sesión ensin contraseñes.",
    "Your connection is not secure" : "La conexón nun ye segura",
    "Passwordless authentication is only available over a secure connection." : "L'autenticación ensin contraseñes namás ta disponible per una conexón segura",
    "Browser not supported" : "El restolador nun ye compatible",
    "Passwordless authentication is not supported in your browser." : "El restolador nun ye compatible cola autenticación ensin contraseñes.",
    "Reset password" : "Reaniciu de la contraseña",
    "Back to login" : "Volver al aniciu de la sesión",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Si esta cuenta esiste, unvióse un mensaxe pa reaniciar la contraseña a esta cuenta. Si nun recibiesti nengún, verifica la direición o la cuenta, comprueba la carpeta de spam o pidi ayuda a l'alministración.",
    "Couldn't send reset email. Please contact your administrator." : "Nun se pudo unviar el mensaxe de reaniciu. Ponte en contautu cola alministración.",
    "Password cannot be changed. Please contact your administrator." : "Nun se pue camudar la contraseña. Ponte en contautu cola alministración.",
    "New password" : "Contraseña nueva",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Los ficheros tán cifraos. Nun va haber forma de recuperalos dempués de reafitar la contraseña. Si nun sabes qué facer, ponte en contautu cola alministración enantes de siguir. ¿De xuru que quies siguir?",
    "I know what I'm doing" : "Sé lo que faigo",
    "Resetting password" : "Reaniciando la contraseña",
    "Schedule work & meetings, synced with all your devices." : "Planifica'l trabayu y les reuniones con sincronización colos tos preseos.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Ten a colegues y amigos nun llugar ensin revelar la so información personal",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Una aplicación de corréu electrónicu cenciella que s'integra bien con Ficheros, Contautos y Calendariu.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Documentos, fueyes de cálculu y presentaciones collaboratives, fechos con Collabora Online.",
    "Distraction free note taking app." : "Una aplicación pa tomar notes ensin distraiciones.",
    "Recommended apps" : "Aplicaciones aconseyaes",
    "Could not fetch list of apps from the App Store." : "Nun se pudo dir en cata de la llista d'aplicaciones de la tienda d'aplicaciones",
    "App download or installation failed" : "La descarga o instalación d'aplicaciones falló",
    "Cannot install this app because it is not compatible" : "Nun se pue instalar esta aplicación porque nun ye compatible",
    "Cannot install this app" : "Nun se pue instalar esta aplicación",
    "Skip" : "Saltar",
    "Install recommended apps" : "Instalar les aplicaciones aconseyaes",
    "Online" : "En llinia",
    "Away" : "Ausente",
    "Busy" : "Ocupáu",
    "Do not disturb" : "Nun molestar",
    "Mute all notifications" : "Desactivar tolos avisos",
    "Invisible" : "Invisible",
    "Appear offline" : "Apaecer desconectáu",
    "Avatar of {displayName}" : "Avatar de: {displayName}",
    "Settings menu" : "Menú de configuración",
    "Search contacts" : "Buscar contautos",
    "Reset search" : "Reaniciar la busca",
    "Could not load your contacts" : "Nun se pudieron cargar los contautos",
    "No contacts found" : "Nun s'atopó nengun contautu",
    "Show all contacts" : "Amostar tolos contautos",
    "Install the Contacts app" : "Instalar l'aplicación Contautos",
    "Search" : "Buscar",
    "No results for {query}" : "Nun hai nengún resultáu pa «{query}»",
    "Press Enter to start searching" : "Primi la tecla «Intro» pa comenzar la busca",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Introduz {minSearchLength} caráuter o más pa buscar","Introduz {minSearchLength} caráuteres o más pa buscar"],
    "An error occurred while searching for {type}" : "Prodúxose un error mentanto se buscaba «{type}»",
    "Search starts once you start typing and results may be reached with the arrow keys" : "La busca comienza namás que comiences a escribir y pues seleicionar los resultaos coles tecles del cursor",
    "Search for {name} only" : "Buscar «{name}» namás",
    "Forgot password?" : "¿Escaeciesti la contraseña?",
    "Back to login form" : "Volver al formulariu p'aniciar la sesión",
    "Back" : "Atrás",
    "Login form is disabled." : "El formulariu p'aniciar la sesión ta desactiváu.",
    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "El formulariu p'aniciar la sesión de Nextcloud ta desactiváu. Usa otra opción p'aniciar la sesión si ta disponible o ponte en contautu cola alministración.",
    "More actions" : "Más aiciones",
    "Security warning" : "Alvertencia de seguranza",
    "Storage & database" : "Almacenamientu y base de datos",
    "Data folder" : "Carpeta de datos",
    "Install and activate additional PHP modules to choose other database types." : "Instala y activa los módulos PHP adicionales pa escoyer otros tipos de bases de datos.",
    "For more details check out the documentation." : "Pa consiguir más detalles, revisa la documentación.",
    "Performance warning" : "Alvertencia tocante al rindimientu",
    "You chose SQLite as database." : "Escoyesti SQLite como base de datos.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite habría usase namás pa instancies mínimes y de desendolcu. Pa sirvidores en producción aconseyamos usar otru backend de base de datos.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Si uses ficheros pa la sincronización de ficheros, l'usu de SQLite nun ye nada aconseyable.",
    "Database user" : "Usuariu de la base de datos",
    "Database password" : "Contraseña de la base de datos",
    "Database name" : "Nome de la base de datos",
    "Database tablespace" : "Espaciu de tabla de la base de datos",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Especifica'l númberu de puertu xunto col nome del agospiador (por exemplu, localhost:5432)",
    "Database host" : "Agospiador de la base de datos",
    "Install" : "Instalar",
    "Need help?" : "¿Precises ayuda?",
    "See the documentation" : "Mira la documentación",
    "{name} version {version} and above" : "{name} versión {version} y superior",
    "This browser is not supported" : "Esti restolador nun ye compatible",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "El restolador nun ye compatible. Anuévalu o instala una versión compatible.",
    "Continue with this unsupported browser" : "SIguir con esti restolador incompatible",
    "Supported versions" : "Versiones compatibles",
    "Choose {file}" : "Escoyer «{file}»",
    "Choose" : "Escoyer",
    "Copy to {target}" : "Copiar a {target}",
    "Copy" : "Copiar",
    "Move to {target}" : "Mover a {target}",
    "Move" : "Mover",
    "OK" : "Normal",
    "read-only" : "de namás llectura",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflictu con ficheros","{count} conflictos con ficheros"],
    "One file conflict" : "Un conflictu con ficheros",
    "New Files" : "Ficheros nuevos",
    "Already existing files" : "Ficheros que yá esisten",
    "Which files do you want to keep?" : "¿Qué ficheros quies caltener?",
    "If you select both versions, the copied file will have a number added to its name." : "Si seleicionaes dambes versiones, va amestase un númberu al nome del ficheru copiáu.",
    "Cancel" : "Encaboxar",
    "Continue" : "Siguir",
    "(all selected)" : "(seleicionóse too)",
    "({count} selected)" : "({count} na seleición)",
    "Error loading file exists template" : "Hebo un error al cargar la plantía de ficheru esistente",
    "seconds ago" : "hai segundos",
    "Connection to server lost" : "Perdióse la conexón col sirividor",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Hebo un problema al cargar la páxina, va volver cargase en %n segundu","Hebo un problema al cargar la páxina, va volver cargase en %n segundos"],
    "Add to a project" : "Amestar al proyeutu",
    "Show details" : "Amosar los detalles",
    "Hide details" : "Esconder los detalles",
    "Rename project" : "Renomar el proyeutu",
    "Failed to rename the project" : "Nun se pue renomar el proyeutu",
    "Failed to create a project" : "Nun se pue crear el proyeutu",
    "Failed to add the item to the project" : "Nun se pue amestar l'elementu al proyeutu",
    "Connect items to a project to make them easier to find" : "Conecta elementos a un proyeutu pa que seyan más fáciles d'atopar",
    "Type to search for existing projects" : "Escribi pa buscar proyeutos esistentes",
    "New in" : "Novedá en",
    "View changelog" : "Ver el rexistru de cambeos",
    "Close \"{dialogTitle}\" dialog" : "Zarrar el diálogu «{dialogTitle}»",
    "Email length is at max (255)" : "La llongura de la direición de corréu electrónicu ye la máxima (255)",
    "Personal" : "Personal",
    "Accounts" : "Cuentes",
    "Admin" : "Alministración",
    "Help" : "Ayuda",
    "Access forbidden" : "Prohíbese l'accesu",
    "Back to %s" : "Volver a «%s»",
    "Page not found" : "Nun s'atopó la páxina",
    "The page could not be found on the server or you may not be allowed to view it." : "Nun se pudo atopar la páxina nel sirvidor o ye posible que nun tengas permisu pa vela.",
    "Too many requests" : "Milenta solicitúes",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Ficiéronse milenta solicitúes dende la to rede. Volvi tentalo dempués o ponte en contautu cola alministración si esti mensaxe ye un error.",
    "Error" : "Error",
    "Internal Server Error" : "Error internu del sirvidor",
    "The server was unable to complete your request." : "El sirividor nun foi a completar la solicitú.",
    "If this happens again, please send the technical details below to the server administrator." : "Si vuelve asoceder, unvia los detalles téunicos d'abaxo a l'alministración del sirvidor.",
    "More details can be found in the server log." : "Pues atopar más detalles nel rexistru del sirvidor.",
    "Technical details" : "Detalles téunicos",
    "Remote Address: %s" : "Direición remota: %s",
    "Request ID: %s" : "ID de la solicitú: %s",
    "Type: %s" : "Tipu: %s",
    "Code: %s" : "Códigu: %s",
    "Message: %s" : "Mensaxe: %s",
    "File: %s" : "Ficheru: %s",
    "Line: %s" : "Llinia: %s",
    "Trace" : "Rastru",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Paez que tentes de volver instalar Nextcloud. Por embargu, falta'l ficheru «CAN_INSTALL» nel ficheru de configuración. Crealu pa siguir.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Nun se pudo quitar el ficheru «CAN_INSTALL» de la carpeta de configuración. Quítalu manualmente.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "L'aplicación rique JavaScript pa funcionar correutamente. {linkstart}Activa JavaScript{linkend} y volvi cargar la páxina.",
    "Skip to main content" : "Saltar al conteníu principal",
    "Skip to navigation of app" : "Saltar a la navegación de l'aplicación",
    "Go to %s" : "Dir a «%s»",
    "Get your own free account" : "Consigui la to cuenta gratuíta",
    "Connect to your account" : "Conectase cola to cuenta",
    "Please log in before granting %1$s access to your %2$s account." : "Anicia la sesión enantes de conceder l'accesu de %1$s na cuenta %2$s.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Si nun tas tentando de configurar un preséu o aplicación nuevos, daquién tenta d'engañate pa que-y concedas l'accesu a los tos datos. Nesi casu nun sigas y ponte en contautu cola alministración.",
    "App password" : "Contraseña de l'aplicación",
    "Grant access" : "Conceder l'accesu",
    "Alternative log in using app password" : "Aniciu de la sesión alternativu cola contraseña de l'aplicación",
    "Account access" : "Accesu a la cuenta",
    "Currently logged in as %1$s (%2$s)." : "Aniciesti la sesión como %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Tas a piques de conceder a «%1$s» l'accesu a la cuenta %2$s.",
    "Account connected" : "Cuenta conectada",
    "Your client should now be connected!" : "¡La cuenta habría tar conectada!",
    "You can close this window." : "Pues zarrar esta ventana.",
    "Previous" : "Anterior",
    "This share is password-protected" : "Esti secrete ta protexíu con una contraseña",
    "The password is wrong or expired. Please try again or request a new one." : "La contraseña ye incorreuta o caducó. Volvi tentalo o solicita una nueva.",
    "Please type in your email address to request a temporary password" : "Escribi la to direición de corréu electrónicu pa solicitar una contraseña temporal",
    "Email address" : "Direición de corréu electrónicu",
    "Password sent!" : "¡Unvióse la contraseña!",
    "You are not authorized to request a password for this share" : "Nun tienes autorización pa solicitar una contraseña pa esta cuenta",
    "Two-factor authentication" : "Autenticación en dos pasos",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Activóse la seguranza ameyorana pa la to cuenta. Escueyi una autenticación en dos pasos:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Nun se pudo cargar, polo menos, unu de los métodos de l'autenticación en dos pasos. Ponte en contautu cola alministración.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "L'autenticación en dos pasos ye obligatoria mas nun se configuró na to cuenta. Ponte en contautu cola alministración pa consiguir más asistencia.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "L'autenticación en dos pasos ye obligatoria mas nun se configuró na to cuenta. Sigui pa configurar l'autenticación en dos pasos.",
    "Set up two-factor authentication" : "Configurar l'autenticación en dos pasos",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "L'autenticación en dos pasos ye obligatoria mas nun se configuró na to cuenta. Usa unu de los códigos de recuperación p'aniciar la sesión o ponte en contautu cola alministración pa consiguir más asistencia.",
    "Use backup code" : "Usar un códigu de recuperación",
    "Cancel login" : "Anular l'aniciu de la sesión",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "La seguranza ameyorada ye obligatoria pa la to cuenta. Escueyi un fornidor pa configurala:",
    "Error while validating your second factor" : "Hebo un error al validar l'autenticación en dos pasos",
    "Access through untrusted domain" : "Acceder pente un dominiu que nun ye d'enfotu",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Ponte en contautu cola alministración. Si yes alministrador, edita la opción «trusted_domain» en config/config.php como nel ficheru d'exemplu config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Pues atopar más más información tocante a cómo configurar esta opción na %1$sdocumentación%2$s.",
    "App update required" : "Ríquese l'anovamientu de l'aplicación",
    "%1$s will be updated to version %2$s" : "%1$s va anovase a la versión %2$s",
    "The following apps will be updated:" : "Van anovase les aplicaciones siguientes:",
    "These incompatible apps will be disabled:" : "Van desactivase esta aplicaciones incompatibles:",
    "The theme %s has been disabled." : "Desactivóse l'estilu «%s».",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Asegúrate de que se ficiere una copia de seguranza de la base de datos, la carpeta de configuración y la de datos enantes de siguir.",
    "Start update" : "Aniciar l'anovamientu",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Pa impidir que s'escose'l tiempu d'espera coles instalaciones grandes, pues executar el comandu siguiente dende'l direutoriu d'instalación:",
    "Detailed logs" : "Rexistros detallaos",
    "Update needed" : "Anovamientu necesariu",
    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Usa l'anovador de la llinia de comandos porque tienes una instancia grande con más de 50 cuentes.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Pa consiguir ayuda, mira la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentación</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Sé que si sigo col anovamientu pela IU web tengo'l riesgu de que la solicitú escose'l tiempu d'espera y causar una perda de datos, más tengo una copia de seguranza y sé cómo restaurar la instancia en casu de fallu.",
    "Upgrade via web on my own risk" : "Anovar pela web baxo'l mio riesgu",
    "Maintenance mode" : "Mou de caltenimientu",
    "This %s instance is currently in maintenance mode, which may take a while." : "Esta instancia de %s ta nel mou de caltenimientu y pue talo un tiempu",
    "This page will refresh itself when the instance is available again." : "Esta páxina va anovase sola cuando la instancia vuelva tar disponible.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Ponte en contautu cola alministración del sistema si esti mensaxe sigue apaeciendo o apaez inesperadamente.",
    "Error occurred while checking server setup" : "Prodúxose un error mentanto se revisaba la configuración del sirvidor",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Pa consiguir más detalles, consulta la {linkstart}documentación ↗{linkend}.",
    "unknown text" : "testu desconocíu",
    "Hello world!" : "¡Hola, mundu!",
    "sunny" : "soleyero",
    "Hello {name}, the weather is {weather}" : "Nola {name}, ta {weather}",
    "Hello {name}" : "Hola, {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Equí tienes los resultaos de la busca<script>alert(1)</script></strong>",
    "new" : "novedá",
    "_download %n file_::_download %n files_" : ["baxar %n ficheru","baxar %n ficheros"],
    "Searching …" : "Buscando…",
    "Logging in …" : "Aniciando la sesión…",
    "Loading apps …" : "Cargando les aplicaciones…",
    "Installing apps …" : "Instalando les aplicaciones…",
    "Loading your contacts …" : "Cargando los contautos…",
    "Looking for {term} …" : "Buscando {term}…",
    "Search contacts …" : "Buscar contautos…",
    "Loading more results …" : "Cargando más resultaos…",
    "Search {types} …" : "Buscar «{types}»…",
    "Saving …" : "Guardando…",
    "Very weak password" : "La contraseña ye mui poco segura",
    "Weak password" : "La contraseña ye poco segura",
    "So-so password" : "La contraseña ye normal",
    "Good password" : "La contraseña ye segura",
    "Strong password" : "La contraseña ye mui segura",
    "No action available" : "Nun hai nenguna aición disponible",
    "Error fetching contact actions" : "Hebo un error al dir en cata de les aiciones del contautu",
    "Non-existing tag #{tag}" : "Etiqueta inesistente #{tag}",
    "Restricted" : "Restrinxóse",
    "Delete" : "Desaniciar",
    "Rename" : "Renomar",
    "Collaborative tags" : "Etiquetes collaboratives",
    "No tags found" : "Nun s'atopó nenguna etiqueta",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Ye probable que'l to direutoriu de datos y los ficheros seyan accesibles dende internet porque'l ficheru .htaccess nun funciona.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Pa consiguir más información tocante a cómo configurar afayadizamente'l sirvidor, mira la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentación</a>.",
    "Show password" : "Amosar la contraseña",
    "Toggle password visibility" : "Alternar la visibilidá de la contraseña",
    "Configure the database" : "Configurar la base de datos",
    "Only %s is available." : "Namás hai disponible %s.",
    "Database account" : "Cuenta de la base de datos",
    "Installing …" : "Instalando…"
},
"nplurals=2; plural=(n != 1);");
